@@ -1,11 +1,11 @@
 ;;; orderless.el --- Completion style for matching regexps in any order  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2021-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2025 Free Software Foundation, Inc.
 
 ;; Author: Omar Antolín Camarena <omar@matem.unam.mx>
 ;; Maintainer: Omar Antolín Camarena <omar@matem.unam.mx>, Daniel Mendler <mail@daniel-mendler.de>
-;; Keywords: extensions
-;; Version: 1.3
+;; Keywords: matching, completion
+;; Version: 1.5
 ;; URL: https://github.com/oantolin/orderless
 ;; Package-Requires: ((emacs "27.1") (compat "30"))
 
@@ -124,7 +124,7 @@ The returned regexps can be either strings or s-expressions in
 the entire match is highlighted, otherwise just the captured
 groups are.  Several are provided with this package: try
 customizing this variable to see a list of them."
-  :type 'hook
+  :type '(repeat function)
   :options (list #'orderless-regexp
                  #'orderless-literal
                  #'orderless-initialism
@@ -199,7 +199,7 @@ the component in the `orderless-flex' style.  See
 `orderless-affix-dispatch' and `orderless-affix-dispatch-alist'
 for such a configuration.  For more information on how this
 variable is used, see `orderless-compile'."
-  :type 'hook)
+  :type '(repeat function))
 
 (defcustom orderless-smart-case t
   "Whether to use smart case.
@@ -370,7 +370,7 @@ converted to a list of regexps according to the value of
                   "\\\\\\\\\\|\\\\ "
                   (lambda (x) (if (equal x "\\ ") (string 0) x))
                   string 'fixedcase 'literal)
-                 " +" t)))
+                 " +")))
 
 (defun orderless--dispatch (dispatchers default string index total)
   "Run DISPATCHERS to compute matching styles for STRING.
@@ -457,9 +457,10 @@ string as argument."
   (unless dispatchers (setq dispatchers orderless-style-dispatchers))
   (cl-loop
    with predicate = nil
-   with components = (if (functionp orderless-component-separator)
-                         (funcall orderless-component-separator pattern)
-                       (split-string pattern orderless-component-separator t))
+   with temp = (if (functionp orderless-component-separator)
+                   (funcall orderless-component-separator pattern)
+                 (split-string pattern orderless-component-separator))
+   with components = (if (equal (car (last temp)) "") (nbutlast temp) temp)
    with total = (length components)
    for comp in components and index from 0
    for (pred . regexp) = (orderless--compile-component
@@ -498,7 +499,7 @@ The predicate PRED is used to constrain the entries in TABLE."
                (prefix (substring string 0 limit))
                (pattern (substring string limit))
                (`(,fun . ,regexps) (orderless-compile pattern)))
-    (list prefix regexps (orderless--ignore-case-p regexps)
+    (list prefix regexps (orderless--ignore-case-p pattern)
           (orderless--predicate-normalized-and pred fun))))
 
 ;; Thanks to @jakanakaevangeli for writing a version of this function:
@@ -519,7 +520,7 @@ then return (cons REGEXP u); else return nil."
 (defun orderless--ignore-case-p (regexps)
   "Return non-nil if case should be ignored for REGEXPS."
   (if orderless-smart-case
-      (cl-loop for regexp in regexps
+      (cl-loop for regexp in (ensure-list regexps)
                always (isearch-no-upper-case-p regexp t))
     completion-ignore-case))
 
